permute_cols

Function permute_cols 

pub fn permute_cols<I: Index, T: ComplexField>(
    dst: MatMut<'_, T>,
    src: MatRef<'_, T>,
    perm_indices: PermRef<'_, I>,
)
computes a permutation of the columns of the source matrix using the given permutation, and stores the result in the destination matrix

panics

  • panics if the matrices do not have the same shape
  • panics if the size of the permutation doesn’t match the number of columns of the matrices