permute_cols_in_place

Function permute_cols_in_place 

pub fn permute_cols_in_place<I: Index, T: ComplexField>(
    matrix: MatMut<'_, T>,
    perm_indices: PermRef<'_, I>,
    stack: &mut MemStack,
)
computes a permutation of the columns of the matrix using the given permutation, and stores the result in the same matrix.

panics

  • panics if the size of the permutation doesn’t match the number of columns of the matrix