permute_cols_in_place_scratch

Function permute_cols_in_place_scratch 

pub fn permute_cols_in_place_scratch<I: Index, T: ComplexField>(
    nrows: usize,
    ncols: usize,
) -> StackReq
computes the size and alignment of required workspace for applying a column permutation to a matrix in place