permute_rows

Function permute_rows 

pub fn permute_rows<I: Index, T: ComplexField>(
    dst: MatMut<'_, T>,
    src: MatRef<'_, T>,
    perm_indices: PermRef<'_, I>,
)
computes a permutation of the rows of the source matrix using the given permutation, and stores the result in the destination matrix

panics

  • panics if the matrices do not have the same shape
  • panics if the size of the permutation doesn’t match the number of rows of the matrices