pub fn permute_rows_in_place<I: Index, T: ComplexField>(
matrix: MatMut<'_, T>,
perm_indices: PermRef<'_, I>,
stack: &mut MemStack,
)Expand description
computes a permutation of the rows of the matrix using the given permutation, and stores the result in the same matrix
panics
- panics if the size of the permutation doesn’t match the number of rows of the matrix